@@ -18,7 +18,7 @@ from typing import Callable, Any
 from typing import List, Dict, Any, Optional
 
 log=logging.getLogger(__name__)
-log.setLevel(logging.INFO)
+log.setLevel(logging.WARNING)
 formatter = logging.Formatter(
     fmt="%(asctime)s | %(levelname)s | %(name)s | %(filename)s:%(lineno)d | %(message)s",
     datefmt="%Y-%m-%d %H:%M:%S"
@@ -34,7 +34,10 @@ class ExecResult():
         self.__exit_status_code = exit_status_code
         self.__stdout = stdout
         self.__stderr = stderr
-        log.info(f" {ip}:{port} | ExecResults: exit_status_code: {exit_status_code},stdout: {stdout}, stderr: {stderr}")
+        if exit_status_code != 0:
+            log.warning(f" {ip}:{port} | ExecResults: exit_status_code: {exit_status_code},stdout: {stdout}, stderr: {stderr}")
+        else:
+            log.info(f" {ip}:{port} | ExecResults: exit_status_code: {exit_status_code},stdout: {stdout}, stderr: {stderr}")
 
     @property
     def exit_status_code(self):
